@@ -17,6 +17,17 @@ DOC_BASIC = <<~ENDOFSTRING
   ----
 ENDOFSTRING
 
+DOC_BASIC_LITERAL = <<~ENDOFSTRING
+  = Hello PlantUML!
+
+  [plantuml, format="png"]
+  .Title Of this
+  ....
+  User -> (Start)
+  User --> (Use the application) : Label
+  ....
+ENDOFSTRING
+
 DOC_BASIC2 = <<~ENDOFSTRING
   = Hello PlantUML!
 
@@ -31,6 +42,20 @@ DOC_BASIC2 = <<~ENDOFSTRING
   ----
 ENDOFSTRING
 
+DOC_BASIC2_LITERAL = <<~ENDOFSTRING
+  = Hello PlantUML!
+
+  [plantuml, format="png"]
+  .Title Of this
+  [[fig-xref]]
+  ....
+  @startuml
+  User -> (Start)
+  User --> (Use the application) : Label
+  @enduml
+  ....
+ENDOFSTRING
+
 DOC_BASIC3 = <<~ENDOFSTRING
   = Hello Compound PlantUML!
 
@@ -43,6 +68,18 @@ DOC_BASIC3 = <<~ENDOFSTRING
   ----
 ENDOFSTRING
 
+DOC_BASIC3_LITERAL = <<~ENDOFSTRING
+  = Hello Compound PlantUML!
+
+  [plantuml, format="png"]
+  ....
+  [COMP1]
+  [COMP2]
+  [COMP1] -> [COMP2]
+  [COMP2] --> [COMP3]
+  ....
+ENDOFSTRING
+
 DOC_ID = <<~ENDOFSTRING
   = Hello PlantUML!
 
@@ -105,6 +142,28 @@ DOC_MULTI = <<~ENDOFSTRING
   ----
 ENDOFSTRING
 
+DOC_MULTI_LITERAL = <<~ENDOFSTRING
+  = Hello PlantUML!
+
+  [plantuml, format="png"]
+  ....
+  User -> (Start)
+  User --> (Use the application) : Label
+  ....
+
+  [plantuml, format="png"]
+  ....
+  User -> (Start)
+  User --> (Use the application) : Label
+  ....
+
+  [plantuml, format="txt"]
+  ....
+  User -> (Start)
+  User --> (Use the application) : Label
+  ....
+ENDOFSTRING
+
 DOC_TXT = <<~ENDOFSTRING
   = Hello PlantUML!
 
@@ -115,15 +174,28 @@ DOC_TXT = <<~ENDOFSTRING
   ----
 ENDOFSTRING
 
+DOC_SVG = <<~ENDOFSTRING
+  = Hello PlantUML!
+
+  [plantuml, format="svg"]
+  ----
+  User -> (Start)
+  User --> (Use the application) : Label
+  ----
+ENDOFSTRING
+
 class PlantUmlTest < Test::Unit::TestCase
   GENURL = 'http://localhost:8080/plantuml/png/U9npA2v9B2efpStX2YrEBLBGjLFG20Q9Q4Bv804WIw4a8rKXiQ0W9pCviIGpFqzJmKh19p4fDOVB8JKl1QWT05kd5wq0'
   GENURL2 = 'http://localhost:8080/plantuml/png/U9npA2v9B2efpStXYdRszmqmZ8NGHh4mleAkdGAAa15G22Pc7Clba9gN0jGE00W75Cm0'
   GENURL_ENCODING = 'http://localhost:8080/plantuml/png/~1U9npA2v9B2efpStX2YrEBLBGjLFG20Q9Q4Bv804WIw4a8rKXiQ0W9pCviIGpFqzJmKh19p4fDOVB8JKl1QWT05kd5wq0'
+  SVGGENURL = 'http://localhost:8080/plantuml/svg/~1U9npA2v9B2efpStX2YrEBLBGjLFG20Q9Q4Bv804WIw4a8rKXiQ0W9pCviIGpFqzJmKh19p4fDOVB8JKl1QWT05kd5wq0'
 
   def setup
     Asciidoctor::PlantUml.configure do |c|
       c.url = 'http://localhost:8080/plantuml'
       c.txt_enable = true
+      c.png_enable = true
+      c.svg_enable = true
     end
   end
 
@@ -140,8 +212,40 @@ class PlantUmlTest < Test::Unit::TestCase
     assert_equal GENURL, element['src']
   end
 
+  def test_plantuml_block_literal_processor
+    html = ::Asciidoctor.convert(
+      StringIO.new(DOC_BASIC_LITERAL), backend: 'html5'
+    )
+    page = Nokogiri::HTML(html)
+
+    elements = page.css('img.plantuml')
+
+    assert_equal elements.size, 1
+
+    element = elements.first
+
+    assert_equal GENURL, element['src']
+  end
+
   def test_plantuml_block_processor2
-    html = ::Asciidoctor.convert(StringIO.new(DOC_BASIC2), backend: 'html5')
+    html = ::Asciidoctor.convert(
+      StringIO.new(DOC_BASIC2), backend: 'html5'
+    )
+    page = Nokogiri::HTML(html)
+
+    elements = page.css('img.plantuml')
+
+    assert_equal elements.size, 1
+
+    element = elements.first
+
+    assert_equal GENURL, element['src']
+  end
+
+  def test_plantuml_block_literal_processor2
+    html = ::Asciidoctor.convert(
+      StringIO.new(DOC_BASIC2_LITERAL), backend: 'html5'
+    )
     page = Nokogiri::HTML(html)
 
     elements = page.css('img.plantuml')
@@ -166,6 +270,21 @@ class PlantUmlTest < Test::Unit::TestCase
     assert_equal GENURL2, element['src']
   end
 
+  def test_plantuml_block_literal_processor3
+    html = ::Asciidoctor.convert(
+      StringIO.new(DOC_BASIC3_LITERAL), backend: 'html5'
+    )
+    page = Nokogiri::HTML(html)
+
+    elements = page.css('img.plantuml')
+
+    assert_equal elements.size, 1
+
+    element = elements.first
+
+    assert_equal GENURL2, element['src']
+  end
+
   def test_plantuml_block_processor_encoding
     Asciidoctor::PlantUml.configure do |c|
       c.encoding = 'deflate'
@@ -229,7 +348,7 @@ class PlantUmlTest < Test::Unit::TestCase
     assert_equal elements.size, 1
   end
 
-  def test_plantuml_multiple
+  def test_plantuml_multiple_listing
     html = ::Asciidoctor.convert(StringIO.new(DOC_MULTI), backend: 'html5')
     page = Nokogiri::HTML(html)
 
@@ -240,6 +359,19 @@ class PlantUmlTest < Test::Unit::TestCase
     assert_equal elements.size, 0
   end
 
+  def test_plantuml_multiple_literal
+    html = ::Asciidoctor.convert(
+      StringIO.new(DOC_MULTI_LITERAL), backend: 'html5'
+    )
+    page = Nokogiri::HTML(html)
+
+    elements = page.css('img.plantuml')
+    assert elements.size >= 2
+
+    elements = page.css('.plantuml-error')
+    assert_equal elements.size, 0
+  end
+
   def test_plantuml_bad_server
     Asciidoctor::PlantUml.configure do |c|
       c.url = 'http://nonexistent.com/plantuml'
@@ -299,4 +431,44 @@ class PlantUmlTest < Test::Unit::TestCase
     elements = page.css('pre.plantuml-error')
     assert_equal elements.size, 1
   end
+
+  def test_svg
+    Asciidoctor::PlantUml.configure do |c|
+      c.url = 'http://localhost:8080/plantuml'
+      c.svg_enable = true
+    end
+
+    html = ::Asciidoctor.convert(StringIO.new(DOC_SVG), backend: 'html5')
+    page = Nokogiri::HTML(html)
+    elements = page.css("object[type='image/svg+xml']")
+    assert_equal elements.size, 1
+
+    element = elements.first
+
+    assert_equal SVGGENURL, element['data']
+  end
+
+  def test_disable_svg
+    Asciidoctor::PlantUml.configure do |c|
+      c.url = 'http://localhost:8080/plantuml'
+      c.svg_enable = false
+    end
+
+    html = ::Asciidoctor.convert(StringIO.new(DOC_SVG), backend: 'html5')
+    page = Nokogiri::HTML(html)
+    elements = page.css('pre.plantuml-error')
+    assert_equal elements.size, 1
+  end
+
+  def test_disable_png
+    Asciidoctor::PlantUml.configure do |c|
+      c.url = 'http://localhost:8080/plantuml'
+      c.png_enable = false
+    end
+
+    html = ::Asciidoctor.convert(StringIO.new(DOC_BASIC_LITERAL), backend: 'html5')
+    page = Nokogiri::HTML(html)
+    elements = page.css('pre.plantuml-error')
+    assert_equal elements.size, 1
+  end
 end
